Package 'dtlg.data'

Title: Benchmark Data for the 'dtlg' Package
Description: A set of datasets to support benchmarking with the package dtlg.
Authors: Max Ebenezer-Brown [aut], Ramiro Magno [aut, cre] (ORCID: <https://orcid.org/0000-0001-5226-3441>), Ascent Digital Services [cph, fnd] (https://www.ascent.io)
Maintainer: Ramiro Magno <[email protected]>
License: CC BY 4.0
Version: 0.2.0
Built: 2026-05-11 07:40:32 UTC
Source: https://github.com/AscentSoftware/dtlg.data

Help Index


Retrieve a bundled dataset

Description

dataset() returns one of the datasets bundled with dtlg.data.

Usage

dataset(name)

Arguments

name

A dataset name. See datasets for a listing of available options.

Value

A bundled dataset as a tibble.

Examples

dataset("adsl_small")

dtlg.data datasets

Description

datasets is a table listing datasets bundled with dtlg.data. Data is generated with the random.cdisc.data package.

Use the name field as input to dataset() to retrieve that dataset into memory.

Usage

datasets

Format

A tibble of bundled datasets of 4 variables:

name

Name of the dataset.

nrow

Number of observations in the dataset.

ncol

Number of variables in the dataset.

description

Brief description of the dataset.

Examples

datasets

Retrieve the label of an object

Description

label() gets the attached label to an object.

Usage

label(x)

Arguments

x

An R object.

Value

The label attribute (string) associated with object passed in x or NULL if the label attribute does not exist.

See Also

with_label()

Examples

label(1)
label(with_label(1, "my label"))

Add a label attribute to an object

Description

Add a label attribute to an object

Usage

with_label(x, label)

Arguments

x

An R object.

label

A label provided as a single string.

Value

x labeled by label.

See Also

label()

Examples

label(1)
label(with_label(1, "my label"))